import ts_module, { CompletionEntry, GetCompletionsAtPositionOptions, UserPreferences } from "typescript/lib/tsserverlibrary";
export interface ToolConfig {
    prefix: string;
    log?: (msg: string) => void;
    actions: ActionConfig[];
    /** prefix to suggest completion - "refactor" by default */
    completionPrefix?: string;
    completionContextFromAst?: (fileName: string, position: number) => {};
}
export interface ActionConfig {
    /** must be a valid JavaScript identifier name */
    name: string;
    /** each must be a valid JavaScript identifier name */
    args: string[];
    /** pretty print for refactor suggestion */
    print: (action: Action) => string;
    /** the example snippet to suggested for this action to the user on "refactor" autocomplete  */
    snippet: string | ((fileName: string, position: number) => string | undefined);
    nameExtra?: string | ((fileName: string, position: number) => string);
    commentType?: 'line' | 'block';
}
export interface Action {
    name: string;
    args: {
        [key: string]: any;
    };
    print: (action: Action) => string;
}
export declare function create(config: ToolConfig): Tool;
export interface Tool {
    /** return all actions found in given file text */
    findActions(fileStr: string): Action[];
    /** helper for generating the complationsAtPosition suggested to the user to prototype its input inquisition */
    getCompletionsAtPosition(fileName: string, position: number, options: GetCompletionsAtPositionOptions | undefined): CompletionEntry[];
    /** helper that implements a generic langauge service method getApplicableRefactors */
    getApplicableRefactors(info: ts_module.server.PluginCreateInfo, refactorName: string, refactorActionName: string, fileName: string, positionOrRange: number | ts.TextRange, userPreferences: UserPreferences): {
        refactors: ts.ApplicableRefactorInfo[];
        selectedAction?: Action;
    };
}
export declare function buildUserCalls(fileStr: string, config: ToolConfig): string[];
